@@ -129,6 +129,8 @@ class TestEnvironment(object):
             data = f.read()
             local_config = json.loads(data % self.options)
 
+        local_config["external_host"] = self.options.get("external_host", None)
+
         return serve.merge_json(default_config, local_config)
 
     def copy_required_files(self):
@@ -511,7 +513,7 @@ class LoggingWrapper(StringIO):
 def list_test_groups(tests_root, metadata_root, test_types, product, **kwargs):
     do_test_relative_imports(tests_root)
 
-    run_info = wpttest.get_run_info(product, debug=False)
+    run_info = wpttest.get_run_info(metadata_root, product, debug=False)
     test_filter = TestFilter(include=kwargs["include"], exclude=kwargs["exclude"],
                              manifest_path=kwargs["include_manifest"])
     test_loader = TestLoader(tests_root, metadata_root, test_filter, run_info)
@@ -522,7 +524,7 @@ def list_test_groups(tests_root, metadata_root, test_types, product, **kwargs):
 
 def list_disabled(tests_root, metadata_root, test_types, product, **kwargs):
     rv = []
-    run_info = wpttest.get_run_info(product, debug=False)
+    run_info = wpttest.get_run_info(metadata_root, product, debug=False)
     test_loader = TestLoader(tests_root, metadata_root, TestFilter(), run_info)
 
     for test_type, tests in test_loader.get_disabled(test_types).iteritems():
@@ -547,7 +549,7 @@ def run_tests(config, tests_root, metadata_root, product, **kwargs):
 
         do_test_relative_imports(tests_root)
 
-        run_info = wpttest.get_run_info(product, debug=False)
+        run_info = wpttest.get_run_info(metadata_root, product, debug=False)
 
         (check_args,
          browser_cls, get_browser_kwargs,
